@@ -5,7 +5,7 @@ import os
 import json
 import hashlib
 from json import JSONDecodeError
-from ..tools import download_from_url, unzip, zipdir
+from ..tools import download_from_url, progressBar, unzip, zipdir, pip_install
 import re
 
 def get_config():
@@ -39,9 +39,10 @@ def rc4_encrypt(data, key):
 def build_package():
     config = get_config()
     PROJECT_NAME = config['project_name']
-    SRC_PROJECT_FOLDER = os.path.join(os.getcwd(), PROJECT_NAME)
+    CWD = os.getcwd()
+    DEV_DEPS = config['dev_dependencies']
+    SRC_PROJECT_FOLDER = os.path.join(CWD, PROJECT_NAME)
     KEY = hashlib.md5(config['crypt_key'].encode()).hexdigest().upper()
-    # IGNORED = [os.path.abspath(x) for x in config['builder']['ignore']]
     TOCOPY = config['builder']['tocopy']
     BUILD_HERE = os.path.abspath(config['builder']['build_folder'])
     TMP_FOLDER = os.path.join(BUILD_HERE, "__TMP__")
@@ -112,6 +113,42 @@ def build_package():
                     with open(dst.replace('.py', EXT), 'wb+') as mb:
                         mb.write(rc4_encrypt(py.read(), KEY))
                         # mb.write(py.read().encode())
+
+    # getting venv dependencies
+    deplist = list()
+    for root, dirs, __ in os.walk(os.path.join(CWD, 'venv', 'Lib', 'site-packages')):
+        for dir in dirs:
+            if dir.endswith('.dist-info'):
+                dep = dir.replace('.dist-info','')
+                dep_version = dep.split('-')[-1]
+                dep_name = dep.replace('-{}'.format(dep_version), '')
+                if dep_name in DEV_DEPS:
+                    continue
+                deplist.append('{}=={}'.format(dep_name, dep_version))
+        break
+
+    print('This dependencies were found:\n\r', *[dep+'\n\r' for dep in deplist])
+    print('installing...')
+    for i, dep in enumerate(deplist):
+        progressBar(i+1, len(deplist))
+        pip_install(PYTHON_FOLDER, dep)
+    print('')
+        
+        
+    print('All requirements has been installed. Clearing a folder')
+    for root, dirs, __ in os.walk(PYTHON_FOLDER):
+        for dir in dirs:
+            if dir.endswith('.dist-info'):
+                print('Removing', dir)
+                shutil.rmtree(os.path.join(root, dir))
+        break
+
+    with open(os.path.join(BUILD_HERE, '.depfile'), 'w+') as f:
+        for dep in deplist:
+            f.write(dep+'\r')
+        f.close()  
+
+
     # getting appversion
 
     mainfile = open(os.path.join(SRC_PROJECT_FOLDER, '__init__.py'), 'r', encoding='utf-8').read()
